# Welcome to reptor (pre-alpha)

**Quickstart**  

*Config:*  
Add config: `reptor conf`

*Upload Evidences:*  
Upload a file: `reptor file myfile.dat`  
Create project note: `echo "Upload this!" | reptor note`  


Happy Hacking!